Attn: Change mpipl target to crash@0 target

To start MPIPL we need to start obmc-host-crash@0.target (changed from
obmc-host-diagnostic-mode@0.target).

Signed-off-by: Ben Tyner <ben.tyner@ibm.com>
Change-Id: I41294357a3f08ea41b320a3b892045f6f0c81f78
diff --git a/attn/ti_handler.cpp b/attn/ti_handler.cpp
index e1dce7c..677cf14 100644
--- a/attn/ti_handler.cpp
+++ b/attn/ti_handler.cpp
@@ -69,9 +69,8 @@
 
     if (autoRebootEnabled())
     {
-        // If autoreboot is enabled we will start diagnostic mode target
-        // which will ultimately mpipl the host.
-        transitionHost(HostState::Diagnostic);
+        // If autoreboot is enabled we will start crash (mpipl) mode target
+        transitionHost(HostState::Crash);
     }
     else
     {